//! # Rational Numbers (fractions)
//!
//! Traits to implement:
//! * Add
//! * AddAssign
//! * Div
//! * DivAssign
//! * Mul
//! * MulAssign
//! * Neg
//! * Sub
//! * SubAssign

use crate::{Sign, Unsigned};
use std::ops::Neg;

#[derive(Debug, Copy, Clone)]
pub enum FracType<T: Unsigned = usize> {
    Proper(T, Frac),
    Improper(Frac),
}

#[derive(Debug, Copy, Clone)]
pub struct Frac<T: Unsigned = usize> {
    numer: T,
    denom: T,
    sign: Sign,
}

impl<T: Unsigned> Frac<T> {
    /// Create a new rational number
    pub fn new(n: T, d: T) -> Self {
        Frac {
            numer: n,
            denom: d,
            sign: Sign::Positive,
        }
    }
}

impl<T: Unsigned> Neg for Frac<T> {
    type Output = Self;

    fn neg(self) -> Self::Output {
        let mut out = self.clone();
        out.sign = !self.sign;

        out
    }
}

#[cfg(test)]
mod tests {

}